@@ -26,7 +26,7 @@ html_dependency_jqueryui <- function() {
 
   htmlDependency(
     name = "jqueryui",
-    version = "1.11.4",
+    version = version_jqueryui,
     src = pkg_file("rmd/h/jqueryui"),
     script = "jquery-ui.min.js")
 }
@@ -153,6 +153,10 @@ theme_version <- function(theme) {
   substr(html_dependency_bootstrap("default")$version, 1, 1)
 }
 
+needs_sass <- function(css) {
+  grepl("\\.s[ac]ss$", css)
+}
+
 
 # Create an HTML dependency for tocify
 #' @rdname html-dependencies
